==> contentsquare-3.8.0.tar.gz: android/src/main/kotlin/com/contentsquare/flutter/infrastructure/core/method_call_executor/agents/WebViewDisposeAgent.kt <==
package com.contentsquare.flutter.infrastructure.core.method_call_executor.agents

import androidx.annotation.VisibleForTesting
import com.contentsquare.flutter.infrastructure.core.method_call_executor.data.ExecutionData
import com.contentsquare.flutter.infrastructure.core.method_call_executor.responses.ExecutionResponse
import com.contentsquare.flutter.infrastructure.core.method_call_executor.responses.FailedExecutionResponse
import com.contentsquare.flutter.infrastructure.core.method_call_executor.responses.FailedExecutionResponseReason
import com.contentsquare.flutter.infrastructure.core.method_call_executor.responses.SuccessExecutionResponse

/**
 * Agent used to execute WebView dispose event.
 */
internal class WebViewDisposeAgent(private val onWebViewDisposeHandler: OnWebViewDisposeHandler = OnWebViewDisposeHandler.dummy()): MethodCallAgent(nativeExceptionMessage) {

    companion object {
        /** Message to use in case of error during native call. */
        const val nativeExceptionMessage = "Failed to handle dispose of WebView"

        /** Message in case of "webview_id" parameter missing. */
        const val missingWebViewIdMessage = "Missing webview_id for the data parameter"

        /** Message in case of "view_id" parameter missing. */
        const val missingViewIdMessage = "Missing view_id for the data parameter"

    }

    override fun execute(data: ExecutionData): ExecutionResponse {
        val webViewId = data.call.argument<Long>("webview_id")
            ?: return FailedExecutionResponse(FailedExecutionResponseReason.MISSING_ARGUMENT, missingWebViewIdMessage, null)

        val viewId = data.call.argument<Long>("view_id")
            ?: return FailedExecutionResponse(FailedExecutionResponseReason.MISSING_ARGUMENT, missingViewIdMessage, null)

        onWebViewDisposeHandler.onWebViewDispose(
            webViewId,
            viewId,
        )

        return SuccessExecutionResponse.empty()
    }

}

/**
 * Handler of the dispose event of a WebView
 */
internal interface OnWebViewDisposeHandler {

    /**
     * Executes when a WebView is disposed with its `webViewId`
     * and `viewId`
     *
     * @param webViewId The ID of the WebView in the ViewGraph
     * @param viewId the ID of the View in the PlatformView of Flutter
     */
    fun onWebViewDispose(webViewId: Long, viewId: Long)

    companion object {
        @VisibleForTesting
        fun dummy(): OnWebViewDisposeHandler {
            return object: OnWebViewDisposeHandler {
                override fun onWebViewDispose(webViewId: Long, viewId: Long) {
                    // Do noting
                }

            }
        }
    }
}

==> contentsquare-3.9.0.tar.gz: android/src/main/kotlin/com/contentsquare/flutter/infrastructure/core/method_call_executor/agents/WebViewDisposeAgent.kt <==
package com.contentsquare.flutter.infrastructure.core.method_call_executor.agents

import androidx.annotation.VisibleForTesting
import com.contentsquare.flutter.infrastructure.core.method_call_executor.data.ExecutionData
import com.contentsquare.flutter.infrastructure.core.method_call_executor.responses.ExecutionResponse
import com.contentsquare.flutter.infrastructure.core.method_call_executor.responses.FailedExecutionResponse
import com.contentsquare.flutter.infrastructure.core.method_call_executor.responses.FailedExecutionResponseReason
import com.contentsquare.flutter.infrastructure.core.method_call_executor.responses.SuccessExecutionResponse
import com.contentsquare.flutter.infrastructure.core.platform_views.WebViewRegistrationManager

/**
 * Agent used to execute WebView dispose event.
 */
internal class WebViewDisposeAgent(private val onWebViewDisposeHandler: OnWebViewDisposeHandler? = WebViewRegistrationManager.getInstance()): MethodCallAgent(nativeExceptionMessage) {

    companion object {
        /** Message to use in case of error during native call. */
        const val nativeExceptionMessage = "Failed to handle dispose of WebView"

        /** Message in case of "webview_id" parameter missing. */
        const val missingWebViewIdMessage = "Missing webview_id for the data parameter"

        /** Message in case of "view_id" parameter missing. */
        const val missingViewIdMessage = "Missing view_id for the data parameter"

    }

    override fun execute(data: ExecutionData): ExecutionResponse {
        val webViewId = data.call.argument<Number>("webview_id")
            ?: return FailedExecutionResponse(FailedExecutionResponseReason.MISSING_ARGUMENT, missingWebViewIdMessage, null)

        val viewId = data.call.argument<Int>("view_id")
            ?: return FailedExecutionResponse(FailedExecutionResponseReason.MISSING_ARGUMENT, missingViewIdMessage, null)

        onWebViewDisposeHandler?.onWebViewDispose(
            webViewId.toLong(),
            viewId,
        )

        return SuccessExecutionResponse.empty()
    }

}

/**
 * Handler of the dispose event of a WebView
 */
internal interface OnWebViewDisposeHandler {

    /**
     * Executes when a WebView is disposed with its `webViewId`
     * and `viewId`
     *
     * @param webViewId The ID of the WebView in the ViewGraph
     * @param viewId the ID of the View in the PlatformView of Flutter
     */
    fun onWebViewDispose(webViewId: Long, viewId: Int)
}
